@@ -17,9 +17,9 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 # 
-# $Id: Autoload.py,v 1.2 1999/08/06 12:49:09 gobry Exp $
+# $Id: Autoload.py,v 1.3 1999/09/02 12:57:31 gobry Exp $
 
-import os
+import os, string
 
 class Loader:
     def __init__ (self, name, url, module):
@@ -63,7 +63,7 @@ def check_by_url (url):
 
 def check_by_name (name):
     for l in __loaders:
-        if l.name == name: l.load ()
+        if string.lower (l.name) == string.lower (name): l.load ()
 
 
 def available ():
