@@ -17,7 +17,7 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 # 
-# $Id: Fields.py,v 1.10 1999/08/25 11:07:31 gobry Exp $
+# $Id: Fields.py,v 1.11 1999/09/02 12:57:31 gobry Exp $
 
 import string, types, re, string
 
@@ -54,7 +54,7 @@ class Access:
 class Author (Access):
     """ Fine description of an author """
     
-    def __init__ (self, copy = None):
+    def __init__ (self, copy = None, strict = 0):
         """ Initialize an author from a string """
 
         if type (copy) is types.StringType:
@@ -64,15 +64,20 @@ class Author (Access):
 
             blocs = string.split (copy, ',')
             if len (blocs) == 1:
-                # last name is after lowercase or is last word
-                words = map (string.strip, string.split (blocs [0]))
-                i = 0
-                while i < len (words) - 1:
-                    if words [i] == string.lower (words [i]): break
-                    i = i + 1
+                if strict:
+                    # strict parsing, the whole block is the last name
+                    self.last  = blocs [0]
+                    self.first = None
+                else:
+                    # lazy parsing, last name is after lowercase or is last word
+                    words = map (string.strip, string.split (blocs [0]))
+                    i = 0
+                    while i < len (words) - 1:
+                        if words [i] == string.lower (words [i]): break
+                        i = i + 1
                     
-                self.first = string.join (words [:i], ' ')
-                self.last  = string.join (words [i:], ' ')
+                    self.first = string.join (words [:i], ' ')
+                    self.last  = string.join (words [i:], ' ')
                 
             elif len (blocs) == 2:
                 self.last  = string.strip (blocs [0])
