@@ -17,7 +17,7 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 # 
-# $Id: Entry.py,v 1.8 1999/09/02 12:57:39 gobry Exp $
+# $Id: Entry.py,v 1.9 1999/09/15 09:29:26 gobry Exp $
 
 from Pyblio.Base import *
 import string, re
@@ -216,7 +216,10 @@ class BasicEditor (GtkHBox):
             self.entry.set_native (self.field, self.native)
             return 1
         
-        if new != self.value:
+        if (new is None and self.value is not None) or \
+           (new is not None and self.value is None) or \
+           new != self.value:
+            
             if new:
                 self.entry [self.field] = new
             else:
