@@ -17,7 +17,7 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 # 
-# $Id: Pybliographic.py,v 1.18 1999/09/02 12:57:39 gobry Exp $
+# $Id: Pybliographic.py,v 1.19 1999/09/15 09:29:26 gobry Exp $
 
 import string, os, urlparse
 
@@ -532,6 +532,11 @@ class Pybliographic (GnomeApp):
     # --------------------------------------------------
 
     def edit_new (self, *arg):
+        if self.database.data is None:
+            d = GnomeOkDialog ("Please, create a new database first.\nUse File/New for example")
+            d.show ()
+            return
+        
         selection = self.database.selection
 
         if not self.database.data.has_property ('add'):
