@@ -18,11 +18,11 @@
  along with this program; if not, write to the Free Software
  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
  
- $Id: accents.c,v 1.8 1999/08/04 09:37:20 gobry Exp $
+ $Id: accents.c,v 1.9 1999/08/31 13:08:46 gobry Exp $
 */
 
 #ifdef HAVE_CONFIG_H
-#include "pyblioconf.h"
+#include "config.h"
 #endif
 
 #include <ctype.h>
