@@ -18,11 +18,11 @@
  along with this program; if not, write to the Free Software
  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
  
- $Id: bibtexmodule.c,v 1.6 1999/08/25 11:07:37 gobry Exp $
+ $Id: bibtexmodule.c,v 1.8 1999/08/31 13:08:50 gobry Exp $
 */
 
 #ifdef HAVE_CONFIG_H
-#include "pyblioconf.h"
+#include "config.h"
 #endif
 
 #include <Python.h>
@@ -119,14 +119,18 @@ bib_open (PyObject * self, PyObject * args)
 {
     char * name;
     BibtexSource * file;
+    gint strictness;
 
     PyBibtexSource_Object * ret;
 
-    if (! PyArg_ParseTuple(args, "s", & name))
+    if (! PyArg_ParseTuple(args, "si", & name, & strictness))
 	return NULL;
 
     file = bibtex_source_new ();
 
+    /* set the strictness */
+    file->strict = strictness;
+
     if (! bibtex_source_file (file, name)) {
 	bibtex_source_destroy (file, TRUE);
 	return NULL;
